==> haskell-enclosed-exceptions-1.0.2-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.2
id: enclosed-exceptions-1.0.2-3ZcMbjN0UPa19tSb4kJRwc
key: enclosed-exceptions-1.0.2-3ZcMbjN0UPa19tSb4kJRwc
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
author: Michael Snoyman, João Cristóvão
exposed: True
exposed-modules:
    Control.Exception.Enclosed
abi: 53c0f0fc7ecaa6874cc30d4f9f988c4a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/enclosed-exceptions-1.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/enclosed-exceptions-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/enclosed-exceptions-1.0.2
hs-libraries: HSenclosed-exceptions-1.0.2-3ZcMbjN0UPa19tSb4kJRwc
depends:
    base-4.9.1.0 deepseq-1.4.2.0
    lifted-base-0.2.3.11-5HGJGSXUc2GCx17d867zNZ
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5 transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enclosed-exceptions-1.0.2-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.2
id: enclosed-exceptions-1.0.2-9FEV8ZJrOpY76VKSD7jnHD
key: enclosed-exceptions-1.0.2-9FEV8ZJrOpY76VKSD7jnHD
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
author: Michael Snoyman, João Cristóvão
exposed: True
exposed-modules:
    Control.Exception.Enclosed
abi: 5e4146d35fab1570fda83f3d00a3ebfc
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/enclosed-exceptions-1.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/enclosed-exceptions-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/enclosed-exceptions-1.0.2
hs-libraries: HSenclosed-exceptions-1.0.2-9FEV8ZJrOpY76VKSD7jnHD
depends:
    base-4.9.1.0 deepseq-1.4.2.0
    lifted-base-0.2.3.11-8iLGwbgzRdj8VUS8VipjzO
    monad-control-1.0.2.2-FLdbJMBsCl8Hxe7Woti7SW transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
